Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bme280_simpletest.py
    :caption: examples/bme280_simpletest.py
    :linenos:

Normal Mode
-----------

Example showing how the BME280 library can be used to set the various
parameters supported by the sensor

.. literalinclude:: ../examples/bme280_normal_mode.py
    :caption: examples/bme280_normal_mode.py
    :linenos:
